alphashape package
==================

Module contents
---------------

.. automodule:: alphashape
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: optimizealpha
    :members:
    :undoc-members:
    :show-inheritance:
